@@ -30,12 +30,10 @@
 #
 
 __doc__ = """
-Contains command line interface for envstack.
+Command line interface for envstack: stacked environment variable management.
 """
 
 import argparse
-import os
-import pprint
 import sys
 import traceback
 
@@ -71,38 +69,45 @@ def parse_args():
     parser.add_argument(
         "namespace",
         metavar="STACK",
-        nargs="?",
-        default=config.DEFAULT_NAMESPACE,
-        help="the environment stack to use (default '%s')" % config.DEFAULT_NAMESPACE,
+        nargs="*",
+        default=[config.DEFAULT_NAMESPACE],
+        help="the environment stacks to use (default '%s')" % config.DEFAULT_NAMESPACE,
+    )
+    parser.add_argument(
+        "--clear",
+        action="store_true",
+        help="generate unset commands for %s" % config.SHELL,
     )
     parser.add_argument(
         "--export",
         action="store_true",
-        help="generate export commands for the current shell",
+        help="generate export commands for %s" % config.SHELL,
     )
     parser.add_argument(
         "-p",
         "--platform",
         default=config.PLATFORM,
         metavar="PLATFORM",
-        help="specify the platform to resolve variables for",
+        help="platform to resolve variables for (linux, darwin, windows)",
     )
     parser.add_argument(
         "-r",
         "--resolve",
+        nargs="*",
         metavar="VAR",
-        help="resolve an environment variable",
-    )
-    parser.add_argument(
-        "--sources",
-        action="store_true",
-        help="list the sources for a stack",
+        help="resolve environment variables",
     )
     parser.add_argument(
         "-t",
         "--trace",
+        nargs="*",
         metavar="VAR",
-        help="trace where a variable is getting set",
+        help="trace where environment variables are being set",
+    )
+    parser.add_argument(
+        "--sources",
+        action="store_true",
+        help="list the env stack file sources",
     )
 
     args = parser.parse_args(args_before_dash)
@@ -115,27 +120,36 @@ def main():
     args, command = parse_args()
 
     try:
-        if args.resolve:
-            env = load_environ(
-                args.namespace, environ=os.environ, platform=args.platform
-            )
-            var = env.get(args.resolve)
-            print(pprint.pformat(expandvars(var, env, recursive=True)))
-        elif args.trace:
-            path = trace_var(args.namespace, args.trace)
-            print("{0}: {1}".format(args.trace, path))
+        if args.resolve is not None:
+            if len(args.resolve) == 0:
+                args.resolve = load_environ(args.namespace).keys()
+            env = load_environ(args.namespace, platform=args.platform)
+            for resolve in args.resolve:
+                var = env.get(resolve)
+                val = expandvars(var, env, recursive=True)
+                print(f"{resolve}={val}")
+        elif args.trace is not None:
+            if len(args.trace) == 0:
+                args.trace = load_environ(args.namespace).keys()
+            for trace in args.trace:
+                path = trace_var(args.namespace, trace)
+                print("{0}: {1}".format(trace, path))
         elif args.sources:
             sources = build_sources(args.namespace)
             for source in sources:
                 print(source)
+        elif args.clear:
+            print(export(args.namespace, config.SHELL, clear=True))
         elif args.export:
             print(export(args.namespace, config.SHELL))
         elif command:
-            return run_command(args.namespace, command)
+            return run_command(command, args.namespace)
         else:
-            env = load_environ(args.namespace, platform=args.platform, includes=True)
+            env = load_environ(
+                args.namespace, environ=None, platform=args.platform, includes=True
+            )
             for k, v in env.items():
-                print(f"{k} {pprint.pformat(v)}")
+                print(f"{k}={v}")
 
     except KeyboardInterrupt:
         print("Stopping...")
