@@ -40,7 +40,7 @@ import string
 from envstack import config, logger, path
 from envstack.exceptions import *
 
-# named variable delimiter pattern
+# value delimiter pattern (splits values by colons or semicolons)
 delimiter_pattern = re.compile("(?![^{]*})[;:]+")
 
 # stores cached file data in memory
@@ -260,13 +260,8 @@ class Env(dict):
         """Returns raw, unexpanded value of key, or None."""
         return self.get(key, resolved=False).template
 
-    def items(self):
-        """Returns list of (key, value) pairs, as 2-tuples."""
-        return [(k, EnvVar(self[k]).value()) for k in self]
-
     def merge(self, env):
-        """Merges another environ into this one, i.e.
-        env[k] will replace self[k].
+        """Merges another env into this one, i.e. env[k] will replace self[k].
 
         :param env: env to merge into this one
         """
@@ -311,7 +306,7 @@ class Source(object):
     def __eq__(self, other):
         if not isinstance(other, Source):
             return False
-        return str(self) == str(other)
+        return self.path == other.path
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -320,7 +315,7 @@ class Source(object):
         return hash(self.__repr__())
 
     def __repr__(self):
-        return '<Source "{}">'.format(self.path)
+        return f'<Source "{self.path}">'
 
     def __str__(self):
         return self.path
@@ -396,61 +391,52 @@ def encode(env, resolved=True):
     return dict((c(k), c(v)) for k, v in env.items())
 
 
-def build_sources(
+def _build_sources(
     name=config.DEFAULT_NAMESPACE,
     scope=None,
     includes=True,
     default=config.DEFAULT_NAMESPACE,
 ):
-    """Builds the list of env source files for a given name.
-    Where the source is in the list of sources depends on its
-    position in the directory tree. Lower scope sources will
-    override higher scope sources, with the default source
-    at the lowest scope position:
-
-        /show/envstack.env
-        /show/seq/envstack.env
-        /show/seq/shot/envstack.env
-        /show/seq/shot/task/envstack.env
-
-    :param name: namespace (base name of .env file).
-    :param scope: environment scope (default: cwd).
-    :param includes: add sources specified in includes.
-    :param default: name of default environment namespace.
-    :returns: list of source files sorted by scope.
-    """
-
-    # stores set of source env files
     sources = []
 
+    # list of included .env files
+    include_sources = []
+
     # scope, or root, of env tree
     path = scope or os.getcwd()
     scope = Scope(scope)
     level, levels = 0, len(scope.levels())
 
-    # the namespaced and default env file names
+    # the namespaced and default .env file names
     named_env = f"{name}.env"
     default_env = f"{default}.env"
 
     def add_source(path):
+        """Adds a source to the list of sources."""
         if not os.path.exists(path):
             return
         if not sources or (sources[0].path != path):
-            s = Source(path)
-            sources.insert(0, s)
-            return s
+            this_source = Source(path)
+            sources.insert(0, this_source)
+            return this_source
 
-    # walk up the directory tree looking for env files
+    def add_includes(src):
+        """Adds included sources to the list of sources and includes."""
+        included = [f"{i}.env" for i in src.includes()]
+        for include_env in included:
+            include_file = os.path.join(config.DEFAULT_ENV_DIR, include_env)
+            if include_env not in include_sources:
+                include_sources.append(include_env)
+            add_source(include_file)
+
+    # walk up the directory tree looking for .env files
     while level < levels:
         named_file = os.path.join(path, named_env)
         src = add_source(named_file)
         if src and includes:
-            included = [f"{i}.env" for i in src.includes()]
-            for include_env in included:
-                include_file = os.path.join(path, include_env)
-                add_source(include_file)
+            add_includes(src)
 
-        # look for a default env file in this scope
+        # look for a default .env file in this scope
         default_file = os.path.join(path, default_env)
         add_source(default_file)
 
@@ -460,24 +446,73 @@ def build_sources(
 
         level += 1
 
-    # check for default namespaced env file
-    named_default = os.path.join(config.DEFAULT_ENV_DIR, named_env)
-    src = add_source(named_default)
+    # look for default include .env files (and their includes)
+    for include_source in include_sources:
+        default_inc_src = add_source(
+            os.path.join(config.DEFAULT_ENV_DIR, include_source)
+        )
+        if default_inc_src and includes:
+            add_includes(default_inc_src)
+
+    # check for default .env file
+    default_src = add_source(os.path.join(config.DEFAULT_ENV_DIR, named_env))
 
     # add included sources
-    if src and includes:
-        included = ["{}.env".format(i) for i in src.includes()]
-        for include_env in included:
-            include_file = os.path.join(config.DEFAULT_ENV_DIR, include_env)
-            add_source(include_file)
+    if default_src and includes:
+        add_includes(default_src)
 
-    # check for global default env file
+    # check for global default .env file
     global_default = os.path.join(config.DEFAULT_ENV_DIR, default_env)
     add_source(global_default)
 
     return sources
 
 
+def build_sources(
+    name=config.DEFAULT_NAMESPACE,
+    scope=None,
+    includes=True,
+    default=config.DEFAULT_NAMESPACE,
+):
+    """Builds the list of env source files for a given name. Where the source
+    is in the list of sources depends on its position in the directory tree.
+    Lower scope sources will override higher scope sources, with the default
+    source at the lowest scope position:
+
+        $DEFAULT_ENV_DIR/stack.env
+        /stack.env
+        /show/stack.env
+        /show/seq/stack.env
+        /show/seq/shot/stack.env
+        /show/seq/shot/task/stack.env
+
+    :param name: list of .env file basenames.
+    :param scope: environment scope (default: cwd).
+    :param includes: add sources specified in includes.
+    :param default: name of default environment namespace.
+    :returns: list of source files sorted by scope.
+    """
+
+    sources = []
+
+    if type(name) == str:
+        namespaces = [name]
+    else:
+        namespaces = name
+
+    for namespace in namespaces:
+        named_sources = _build_sources(
+            name=namespace,
+            scope=scope,
+            includes=includes,
+            default=default,
+        )
+        if named_sources:
+            sources.extend(named_sources)
+
+    return sources
+
+
 def expandvars(var, env=None, recursive=False):
     """Expands variables in a given string for a given environment,
     e.g.: if env = {'ROOT':'/projects'}
@@ -494,33 +529,52 @@ def expandvars(var, env=None, recursive=False):
     return EnvVar(var).expand(env, recursive=recursive)
 
 
-def export(name, shell="bash", resolve=False, scope=None):
+def export(name, shell="bash", resolve=False, scope=None, clear=False):
     """Returns environment commands that can be sourced.
 
        $ source <(envstack --export)
 
-    List of shell names: bash, tcsh, cmd, pwsh
+    or to clear existing values:
+
+        $ source <(envstack --clear)
+
+    List of shell names: bash, sh, tcsh, cmd, pwsh
     (see output of config.detect_shell()).
 
-    :param name: stack namespace
-    :param shell: name of shell (default: bash)
-    :param resolve: resolve values (default: True)
-    :param scope: environment scope (default: cwd)
-    :returns: shell commands as string
+    :param name: stack namespace.
+    :param shell: name of shell (default: bash).
+    :param resolve: resolve values (default: True).
+    :param scope: environment scope (default: cwd).
+    :param clear: clear existing values (default: False).
+    :returns: shell commands as string.
     """
     env = load_environ(name, scope=scope)
     expList = list()
     for k, v in env.items():
         if resolve:
             v = expandvars(v, env, recursive=False)
-        if shell == "bash":
-            expList.append('export {0}="{1}"'.format(k, v))
+        if shell in ["bash", "sh", "zsh"]:
+            if clear:
+                expList.append(f"unset {k}")
+            else:
+                expList.append(f'export {k}="{v}"')
         elif shell == "tcsh":
-            expList.append('setenv {0}:"{1}"'.format(k, v))
+            if clear:
+                expList.append(f"unsetenv {k}")
+            else:
+                expList.append(f'setenv {k}:"{v}"')
         elif shell == "cmd":
-            expList.append('set {0}="{1}"'.format(k, v))
+            if clear:
+                expList.append(f"set {k}=")
+            else:
+                expList.append(f'set {k}="{v}"')
         elif shell == "pwsh":
-            expList.append('$env:{0}="{1}"'.format(k, v))
+            if clear:
+                expList.append(f"Remove-Item Env:{k}")
+            else:
+                expList.append(f'$env:{k}="{v}"')
+        elif shell == "unknown":
+            raise Exception("unknown shell")
     expList.sort()
     exp = "\n".join(expList)
     return exp
@@ -538,7 +592,7 @@ def init(name=config.DEFAULT_NAMESPACE):
 def load_environ(
     name=config.DEFAULT_NAMESPACE,
     sources=None,
-    environ=None,
+    environ=os.environ,
     platform=config.PLATFORM,
     scope=None,
     includes=True,
@@ -563,7 +617,7 @@ def load_environ(
     :returns: dict of environment variables.
     """
 
-    # build list of sources from scope
+    # build list of sources from namespace(s) and scope
     if not sources:
         sources = build_sources(name, scope=scope, includes=includes)
 
@@ -577,9 +631,9 @@ def load_environ(
     for source in sources:
         env.update(source.load(platform=platform))
 
-    # load values from local environment
+    # merge values from given environment
     if environ:
-        env.merge(environ)
+        return merge(env, environ, platform=platform)
 
     return env
 
@@ -616,11 +670,52 @@ def load_file(path):
     return data
 
 
-def safe_eval(value):
-    """Returns template value preserving original class.
-    Useful for preserving nested values in wrappers.
-    """
+def merge(env, other, strict=False, platform=config.PLATFORM):
+    """Merges values from other into env. For example, to merge values from
+    the local environment into an env instance:
 
+        >>> merge(env, os.environ)
+
+    To merge values from env into the local environment:
+
+        >>> merge(os.environ, env)
+
+    :param env: source env
+    :param other: env to merge
+    :param strict: value from env takes precedence (default: False)
+    :param platform: name of platform (linux, darwin, windows)
+    :returns: merged env
+    """
+    merged = env.copy()
+    for key, value in merged.items():
+        var = "${%s}" % key
+        if key in other:
+            if var in str(value):
+                value = re.sub(
+                    r"\${(\w+)}",
+                    lambda match: other.get(match.group(1), match.group(0)),
+                    value,
+                )
+            elif not strict:
+                value = other.get(key)
+        else:
+            value = str(value).replace(var, "")
+        if platform == "windows":
+            result = re.sub(r"(?<!\b[A-Za-z]):", ";", str(value))
+            value = result.rstrip(";")
+        merged[key] = value
+    return merged
+
+
+def safe_eval(value):
+    """
+    Returns template value preserving original class. Useful for preserving
+    nested values in wrappers. For example, a value of "1.0" returns 1.0, and a
+    value of "['a', 'b']" returns ['a', 'b'].
+
+    :param value: value to evaluate
+    :returns: evaluated value
+    """
     try:
         from ast import literal_eval
 
@@ -650,7 +745,7 @@ def trace_var(name, var, scope=None):
     :returns: source path
     """
     if var in os.environ:
-        return "local environment (unset to clear)"
+        return "local environment"
     sources = build_sources(name, scope=scope)
     sources.reverse()
     for source in sources:
@@ -660,6 +755,7 @@ def trace_var(name, var, scope=None):
             return source.path
 
 
+# default stack environment
 environ = load_environ(environ=os.environ)
 
 
